#
# spec file for package ghc-pandoc-lua-marshal
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name pandoc-lua-marshal
%global pkgver %{pkg_name}-%{version}
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.3.0
Release:        1.5
Summary:        Use pandoc types in Lua
License:        MIT
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-aeson-prof
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-containers-prof
BuildRequires:  ghc-exceptions-devel
BuildRequires:  ghc-exceptions-prof
BuildRequires:  ghc-hslua-devel
BuildRequires:  ghc-hslua-list-devel
BuildRequires:  ghc-hslua-list-prof
BuildRequires:  ghc-hslua-marshalling-devel
BuildRequires:  ghc-hslua-marshalling-prof
BuildRequires:  ghc-hslua-prof
BuildRequires:  ghc-pandoc-types-devel
BuildRequires:  ghc-pandoc-types-prof
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-safe-devel
BuildRequires:  ghc-safe-prof
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-text-prof
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-QuickCheck-prof
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-hunit-prof
BuildRequires:  ghc-tasty-lua-devel
BuildRequires:  ghc-tasty-lua-prof
BuildRequires:  ghc-tasty-prof
BuildRequires:  ghc-tasty-quickcheck-devel
BuildRequires:  ghc-tasty-quickcheck-prof
%endif

%description
This package provides functions to marshal and unmarshal pandoc document types
to and from Lua.

The values of most types are pushed to pandoc as "userdata" objects that wrap a
stable pointer to the Haskell value; these objects come with methods to access
and modify their properties.

Sequences are pushed as normal Lua tables, but are augmented with convenience
functions.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development
files.

%package -n ghc-%{pkg_name}-doc
Summary:        Haskell %{pkg_name} library documentation
Requires:       ghc-filesystem
BuildArch:      noarch

%description -n ghc-%{pkg_name}-doc
This package provides the Haskell %{pkg_name} library documentation.

%package -n ghc-%{pkg_name}-prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       ghc-%{pkg_name}-devel = %{version}-%{release}
Supplements:    (ghc-%{pkg_name}-devel and ghc-prof)

%description -n ghc-%{pkg_name}-prof
This package provides the Haskell %{pkg_name} profiling library.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md README.md

%files -n ghc-%{pkg_name}-doc -f ghc-%{pkg_name}-doc.files
%license LICENSE

%files -n ghc-%{pkg_name}-prof -f ghc-%{pkg_name}-prof.files

%changelog
* Sat Dec  7 2024 Peter Simons <psimons@suse.com>
- Update pandoc-lua-marshal to version 0.3.0.
  [#]# 0.3.0
  Released 2024-12-07.
  * Add method `normalize` to Pandoc objects.
    This returns a normalized document by merging adjacent spaces in inlines
    and by modifying tables.
  * Push Captions as userdata, move code to separate module.
  * Add tests for RawInline and its properties
  * Allow treatment of custom elements as singleton lists.
  * Remove `pandoc` prefix on table components (jgm/pandoc#8574).
* Tue Oct  1 2024 Peter Simons <psimons@suse.com>
- Update pandoc-lua-marshal to version 0.2.9.
  [#]# 0.2.9
  Released 2024-10-01.
  - Update list module, thereby introducing a new method `iter`;
    the function returns an iterator that steps through list
    values on each call.
  - Added support for `__toinline` and `__toblock` metamethods. If
    the metamethods are available on a Lua object and return an
    appropriate value, then that returned value will be used
    during unmarshalling.
  [#]# 0.2.8
  Released 2024-09-21.
  - Update list module, thereby introducing a new method `at` and
    an extended constructor for List types.
* Tue Jul  2 2024 Peter Simons <psimons@suse.com>
- Update pandoc-lua-marshal to version 0.2.7.1.
  [#]# 0.2.7.1
  Released 2024-07-02.
  - Relaxed the upper bound of tasty-quickcheck, used in tests.
    Now allows version 0.11.
  - Update documentation on constructors; the descriptions now
    match those in the pandoc docs.
* Mon May  6 2024 Peter Simons <psimons@suse.com>
- Update pandoc-lua-marshal to version 0.2.7.
  [#]# 0.2.7
  Released 2024-05-06.
  - Let the behavior of `content` attributes on BulletList and
    OrderedList elements match that of the constructor by treating
    a list of Block elements as a list of single-block items. The
    following assertion now holds true:
    ``` lua
    local content = {pandoc.Plain "one", pandoc.Plain "two"}
    local bl = pandoc.BulletList{}
    bl.content = content
    assert(bl == pandoc.BulletList(content))
    ```
* Tue Apr 23 2024 Peter Simons <psimons@suse.com>
- Update pandoc-lua-marshal to version 0.2.6 revision 1.
  Upstream has revised the Cabal build instructions on Hackage.
* Fri Mar 29 2024 Peter Simons <psimons@suse.com>
- Update pandoc-lua-marshal to version 0.2.6.
  [#]# 0.2.6
  Released 2024-03-29.
  - Fixed a bug that caused problems with empty Block lists in
    the `content` attributes of *Div*, *Figure*, and *BlockQuote*
    elements.
* Mon Mar  4 2024 Peter Simons <psimons@suse.com>
- Update pandoc-lua-marshal to version 0.2.5.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/pandoc-lua-marshal-0.2.5/src/CHANGELOG.md
* Fri Jan 19 2024 Peter Simons <psimons@suse.com>
- Update pandoc-lua-marshal to version 0.2.4.
  [#]# 0.2.3
  Released 2024-01-19.
  - Relaxed upper bound for aeson, allowing aeson-2.2.\*.
  [#]# 0.2.3
  Released 2024-01-19.
  - Relaxed upper bound for text, containers, and bytestring,
    allowing text-2.1, containers-0.7, and bytestring-0.12.
* Thu Mar 30 2023 Peter Simons <psimons@suse.com>
- Updated spec file to conform with ghc-rpm-macros-2.5.2.
* Wed Mar 15 2023 Peter Simons <psimons@suse.com>
- Update pandoc-lua-marshal to version 0.2.2.
  [#]# 0.2.2
  Released 2023-03-15.
  - Add `__tostring` metamethods to *Blocks* and *Inlines*.
* Mon Mar 13 2023 Peter Simons <psimons@suse.com>
- Update pandoc-lua-marshal to version 0.2.1.1.
  [#]# 0.2.1.1
  Released 2023-03-13.
  - The version constraints for hslua packages have been relaxed;
    other changes in hslua 2.3.\* do not affect this package.
* Sat Feb 11 2023 Peter Simons <psimons@suse.com>
- Update pandoc-lua-marshal to version 0.2.1.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/pandoc-lua-marshal-0.2.1/src/CHANGELOG.md
* Wed Jan 18 2023 Peter Simons <psimons@suse.com>
- Update pandoc-lua-marshal to version 0.2.0.
  [#]# 0.2.0
  Release pending.
  - Depend on pandoc-types 1.23: the `Null` Block constructor has
    been removed, and a `Figure` constructor has been added.
  - Support for Lua 5.3 has been dropped; the package now requires
    hslua 2.2 or later.
  - The implementation for `List` has been moved to the separate
    `hslua-list` module. This module no longer contains C code.
* Sat Jul 16 2022 Peter Simons <psimons@suse.com>
- Update pandoc-lua-marshal to version 0.1.7.
  [#]# 0.1.7
  Released 2022-07-16.
  - Allow Blocks to be passed as Caption value. The resulting
    caption has the Blocks as its long version and no short
    version.
  - Add `clone` method to Pandoc elements.
* Fri Jun 10 2022 Peter Simons <psimons@suse.com>
- Update pandoc-lua-marshal to version 0.1.6.1.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/pandoc-lua-marshal-0.1.6.1/src/CHANGELOG.md
* Sat Feb 19 2022 Peter Simons <psimons@suse.com>
- Update pandoc-lua-marshal to version 0.1.5.1.
  [#]# 0.1.5.1
  Release pending.
  - Relax upper bound for lua and hslua.
* Thu Feb 17 2022 Peter Simons <psimons@suse.com>
- Update pandoc-lua-marshal to version 0.1.5.
  [#]# 0.1.5
  Released 2022-02-17.
  - Allow any type of callable object as argument to List
    functions `filter`, `map`, and `find_if`. These previously
    required the argument to be of type `function`, which was too
    restrictive.
  - Inline: the type of Image captions is now `Inlines` instead
    of `List`.
* Fri Feb  4 2022 psimons@suse.com
- Add pandoc-lua-marshal at version 0.1.4.
